Package: spacc
Title: Fast Spatial Species Accumulation Curves
Version: 0.8.3
Authors@R: 
    person("Gilles", "Colling", , "gilles.colling051@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0003-3070-6066"))
Description: High-performance spatial species accumulation curves using
    nearest-neighbor algorithms. Implements 'kNN' and 'kNCN' sampling methods
    with a 'C++' backend for speed. Supports Hill numbers (q=0,1,2), beta
    diversity partitioning (turnover/nestedness), coverage-based rarefaction
    and extrapolation, phylogenetic diversity (Faith's PD, mean pairwise
    distance, mean nearest taxon distance), functional diversity accumulation,
    diversity-area relationships (DAR), endemism-area curves, sampling-effort
    correction and fragmentation analysis, and species-area relationship (SAR)
    models based on extreme value theory (EVT). Multiple starting points
    (seeds) provide uncertainty quantification.
    Methods are described in 'Chao' et al. (2014) <doi:10.1890/13-0133.1>,
    'Baselga' (2010) <doi:10.1111/j.1466-8238.2009.00490.x>,
    'Chao' and 'Jost' (2012) <doi:10.1890/11-1952.1>,
    'Faith' (1992) <doi:10.1016/0006-3207(92)91201-3>,
    'Ma' (2018) <doi:10.1002/ece3.4526>,
    'Borda-de-Agua' et al. (2025) <doi:10.1038/s41467-025-59239-7>,
    'Hanski' et al. (2013) <doi:10.1073/pnas.1311190110>,
    and 'Jost' (2007) <doi:10.1890/06-1736.1>.
License: MIT + file LICENSE
Language: en-US
Encoding: UTF-8
Depends: R (>= 3.5)
LinkingTo: Rcpp, RcppParallel
Imports: Rcpp, RcppParallel, stats, parallel
Suggests: testthat (>= 3.0.0), knitr, rmarkdown, svglite, ggplot2, cli,
        sf, areaOfEffect, ape, iNEXT, betapart, cluster
Config/testthat/edition: 3
VignetteBuilder: knitr
SystemRequirements: GNU make
URL: https://gillescolling.com/spacc/, https://github.com/gcol33/spacc
BugReports: https://github.com/gcol33/spacc/issues
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-06-14 13:19:29 UTC; Gilles Colling
Author: Gilles Colling [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-3070-6066>)
Maintainer: Gilles Colling <gilles.colling051@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-20 13:40:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-06-20 14:28:01 UTC; unix
Archs: spacc.so.dSYM
