# Generated by roxygen2: do not edit by hand

S3method("[",spacc)
S3method(as.data.frame,spacc)
S3method(as.data.frame,spacc_alpha)
S3method(as.data.frame,spacc_beta)
S3method(as.data.frame,spacc_beta_decay)
S3method(as.data.frame,spacc_comp)
S3method(as.data.frame,spacc_completeness)
S3method(as.data.frame,spacc_coverage)
S3method(as.data.frame,spacc_dar)
S3method(as.data.frame,spacc_decay)
S3method(as.data.frame,spacc_endemism)
S3method(as.data.frame,spacc_estimate)
S3method(as.data.frame,spacc_evenness)
S3method(as.data.frame,spacc_fit)
S3method(as.data.frame,spacc_func)
S3method(as.data.frame,spacc_hill)
S3method(as.data.frame,spacc_hill_beta)
S3method(as.data.frame,spacc_hill_coverage)
S3method(as.data.frame,spacc_mem)
S3method(as.data.frame,spacc_metrics)
S3method(as.data.frame,spacc_model_compare)
S3method(as.data.frame,spacc_partition)
S3method(as.data.frame,spacc_phylo)
S3method(as.data.frame,spacc_profile)
S3method(as.data.frame,spacc_rare)
S3method(as.data.frame,spacc_ses)
S3method(as.data.frame,spacc_wavefront)
S3method(as.data.frame,spacc_zeta)
S3method(as_sf,spacc_alpha)
S3method(as_sf,spacc_beta)
S3method(as_sf,spacc_completeness)
S3method(as_sf,spacc_coverage)
S3method(as_sf,spacc_endemism)
S3method(as_sf,spacc_evenness)
S3method(as_sf,spacc_func)
S3method(as_sf,spacc_hill)
S3method(as_sf,spacc_metrics)
S3method(as_sf,spacc_partition)
S3method(as_sf,spacc_phylo)
S3method(as_sf,spacc_profile)
S3method(as_sf,spacc_ses)
S3method(c,spacc)
S3method(c,spacc_beta)
S3method(c,spacc_coverage)
S3method(c,spacc_hill)
S3method(coef,spacc_beta_decay)
S3method(coef,spacc_fit)
S3method(coef,spacc_model_compare)
S3method(confint,spacc_fit)
S3method(distances,data.frame)
S3method(distances,sf)
S3method(distances,sfc)
S3method(ggplot2::autoplot, spacc)
S3method(ggplot2::autoplot, spacc_beta)
S3method(ggplot2::autoplot, spacc_completeness)
S3method(ggplot2::autoplot, spacc_coverage)
S3method(ggplot2::autoplot, spacc_decay)
S3method(ggplot2::autoplot, spacc_endemism)
S3method(ggplot2::autoplot, spacc_fit)
S3method(ggplot2::autoplot, spacc_hill)
S3method(ggplot2::autoplot, spacc_hill_beta)
S3method(ggplot2::autoplot, spacc_hill_coverage)
S3method(ggplot2::autoplot, spacc_mem)
S3method(ggplot2::autoplot, spacc_mem_partition)
S3method(ggplot2::autoplot, spacc_metrics)
S3method(ggplot2::autoplot, spacc_model_compare)
S3method(ggplot2::autoplot, spacc_rare)
S3method(ggplot2::autoplot, spacc_ses)
S3method(ggplot2::autoplot, spacc_zeta)
S3method(plot,spacc)
S3method(plot,spacc_alpha)
S3method(plot,spacc_beta)
S3method(plot,spacc_beta_decay)
S3method(plot,spacc_comp)
S3method(plot,spacc_completeness)
S3method(plot,spacc_coverage)
S3method(plot,spacc_coverage_ext)
S3method(plot,spacc_dar)
S3method(plot,spacc_decay)
S3method(plot,spacc_dist)
S3method(plot,spacc_diversity)
S3method(plot,spacc_endemism)
S3method(plot,spacc_estimate)
S3method(plot,spacc_evenness)
S3method(plot,spacc_fit)
S3method(plot,spacc_func)
S3method(plot,spacc_hill)
S3method(plot,spacc_hill_beta)
S3method(plot,spacc_hill_coverage)
S3method(plot,spacc_mem)
S3method(plot,spacc_mem_partition)
S3method(plot,spacc_metrics)
S3method(plot,spacc_model_compare)
S3method(plot,spacc_partition)
S3method(plot,spacc_phylo)
S3method(plot,spacc_profile)
S3method(plot,spacc_rare)
S3method(plot,spacc_ses)
S3method(plot,spacc_sesars)
S3method(plot,spacc_sfar)
S3method(plot,spacc_wavefront)
S3method(plot,spacc_zeta)
S3method(predict,spacc)
S3method(predict,spacc_fit)
S3method(predict,spacc_model_compare)
S3method(print,spacc)
S3method(print,spacc_alpha)
S3method(print,spacc_beta)
S3method(print,spacc_beta_decay)
S3method(print,spacc_comp)
S3method(print,spacc_completeness)
S3method(print,spacc_coverage)
S3method(print,spacc_coverage_ext)
S3method(print,spacc_dar)
S3method(print,spacc_decay)
S3method(print,spacc_dist)
S3method(print,spacc_diversity)
S3method(print,spacc_endemism)
S3method(print,spacc_estimate)
S3method(print,spacc_evenness)
S3method(print,spacc_fit)
S3method(print,spacc_func)
S3method(print,spacc_hill)
S3method(print,spacc_hill_beta)
S3method(print,spacc_hill_coverage)
S3method(print,spacc_mem)
S3method(print,spacc_mem_partition)
S3method(print,spacc_metrics)
S3method(print,spacc_model_compare)
S3method(print,spacc_partition)
S3method(print,spacc_phylo)
S3method(print,spacc_profile)
S3method(print,spacc_rare)
S3method(print,spacc_ses)
S3method(print,spacc_sesars)
S3method(print,spacc_sfar)
S3method(print,spacc_wavefront)
S3method(print,spacc_zeta)
S3method(print,summary.spacc)
S3method(print,summary.spacc_decay)
S3method(print,summary.spacc_rare)
S3method(summary,spacc)
S3method(summary,spacc_alpha)
S3method(summary,spacc_beta)
S3method(summary,spacc_beta_decay)
S3method(summary,spacc_comp)
S3method(summary,spacc_completeness)
S3method(summary,spacc_coverage)
S3method(summary,spacc_coverage_ext)
S3method(summary,spacc_dar)
S3method(summary,spacc_decay)
S3method(summary,spacc_endemism)
S3method(summary,spacc_estimate)
S3method(summary,spacc_evenness)
S3method(summary,spacc_fit)
S3method(summary,spacc_func)
S3method(summary,spacc_hill)
S3method(summary,spacc_hill_beta)
S3method(summary,spacc_hill_coverage)
S3method(summary,spacc_mem)
S3method(summary,spacc_mem_partition)
S3method(summary,spacc_metrics)
S3method(summary,spacc_model_compare)
S3method(summary,spacc_partition)
S3method(summary,spacc_phylo)
S3method(summary,spacc_profile)
S3method(summary,spacc_rare)
S3method(summary,spacc_ses)
S3method(summary,spacc_sesars)
S3method(summary,spacc_sfar)
S3method(summary,spacc_wavefront)
S3method(summary,spacc_zeta)
export(ace)
export(alphaDiversity)
export(as_sf)
export(betaDecay)
export(bootstrap_richness)
export(chao1)
export(chao2)
export(coleman)
export(collector)
export(compare)
export(compareModels)
export(completenessProfile)
export(dar)
export(distanceDecay)
export(distances)
export(diversityPartition)
export(diversityProfile)
export(diversityProfileFunc)
export(diversityProfilePhylo)
export(evenness)
export(extrapolate)
export(extrapolateCoverage)
export(gammaDiversity)
export(iChao1)
export(iChao2)
export(interpolateCoverage)
export(jackknife)
export(mao_tau)
export(rarefy)
export(ses)
export(sesars)
export(sfar)
export(spacc)
export(spaccBeta)
export(spaccBetaFunc)
export(spaccBetaPhylo)
export(spaccCoverage)
export(spaccDiversity)
export(spaccEndemism)
export(spaccFunc)
export(spaccHill)
export(spaccHillBeta)
export(spaccHillCoverage)
export(spaccMetrics)
export(spaccPhylo)
export(spatialEigenvectors)
export(spatialPartition)
export(spatialRarefaction)
export(subsample)
export(wavefront)
export(zetaDiversity)
importFrom(Rcpp,sourceCpp)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(parallel,detectCores)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,anova)
importFrom(stats,approx)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,dist)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,nls)
importFrom(stats,nls.control)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,sd)
useDynLib(spacc, .registration = TRUE)
